@@ -2,13 +2,12 @@ package datatools
 
 import (
 	"github.com/lmorg/murex/lang"
+	"github.com/lmorg/murex/lang/types"
 )
 
 func init() {
-	lang.GoFunctions["swivel-table"] = cmdSwivelTable
-	//lang.DefineFunction("swivel-table", cmdSwivelTable, types.ReadMap, types.Marshal)
-	lang.GoFunctions["swivel-datatype"] = cmdSwivelDataType
-	//lang.DefineFunction("swivel-datatype", cmdSwivelDataType, types.ReadMap, types.Marshal)
+	lang.DefineMethod("swivel-table", cmdSwivelTable, types.ReadMap, types.Marshal)
+	lang.DefineMethod("swivel-datatype", cmdSwivelDataType, types.ReadMap, types.Marshal)
 }
 
 func cmdSwivelDataType(p *lang.Process) error {
